"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const http_1 = require("http");
const inject_1 = require("@furystack/inject");
const utils_1 = require("@furystack/utils");
const login_1 = require("./login");
const http_user_context_1 = require("../http-user-context");
describe('LoginAction', () => {
    /** */
    it('Returns the provided user with 200 on success', async () => {
        const testUser = { Name: 'Userke' };
        await utils_1.usingAsync(new inject_1.Injector(), async (i) => {
            i.setExplicitInstance({
                authenticateUser: jest.fn(async () => testUser),
                cookieLogin: jest.fn(async () => testUser),
                authentication: {},
            }, http_user_context_1.HttpUserContext);
            i.setExplicitInstance({ readPostBody: async () => ({}) }, http_1.IncomingMessage);
            i.setExplicitInstance({}, http_1.ServerResponse);
            const result = await login_1.LoginAction(i);
            expect(result.chunk).toBe(JSON.stringify(testUser));
            expect(result.statusCode).toBe(200);
        });
    });
    it('Returns error with 400 on fail', async () => {
        await utils_1.usingAsync(new inject_1.Injector(), async (i) => {
            i.setExplicitInstance({ cookieLogin: async () => Promise.reject(':(') }, http_user_context_1.HttpUserContext);
            i.setExplicitInstance({ readPostBody: async () => ({}) }, http_1.IncomingMessage);
            i.setExplicitInstance({}, http_1.ServerResponse);
            const result = await login_1.LoginAction(i);
            expect(result.statusCode).toBe(400);
            expect(result.chunk).toBe(JSON.stringify({ message: 'Login failed' }));
        });
    });
});
//# sourceMappingURL=login-action.spec.js.map