"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const http_user_context_1 = require("../http-user-context");
const request_action_1 = require("../models/request-action");
require("../injector-extensions");
/**
 * Action that logs in the current user
 * Should be called with a JSON Post body with ``username`` and ``password`` fields.
 * Returns the current user instance
 */
exports.LoginAction = async (injector) => {
    const msg = injector.getRequest();
    const userContext = injector.getInstance(http_user_context_1.HttpUserContext);
    const response = injector.getResponse();
    const loginData = await msg.readPostBody();
    try {
        const user = await userContext.authenticateUser(loginData.username, loginData.password);
        await userContext.cookieLogin(user, response);
        return request_action_1.JsonResult(user);
    }
    catch (error) {
        return request_action_1.JsonResult({
            message: 'Login failed',
        }, 400);
    }
};
//# sourceMappingURL=login.js.map