"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const http_1 = require("http");
const inject_1 = require("@furystack/inject");
const utils_1 = require("@furystack/utils");
const http_user_context_1 = require("./http-user-context");
const request_action_1 = require("./models/request-action");
const authenticate_1 = require("./authenticate");
describe('Authenticate', () => {
    it('Should return 403 w/o basic auth header, when unauthorized and basic auth is disabled', async () => {
        await utils_1.usingAsync(new inject_1.Injector(), async (i) => {
            const isAuthenticatedAction = jest.fn(async () => false);
            i.setExplicitInstance({ url: 'http://google.com' }, http_1.IncomingMessage);
            i.setExplicitInstance({
                isAuthenticated: isAuthenticatedAction,
                getCurrentUser: async () => Promise.reject(':('),
                authentication: { enableBasicAuth: false },
            }, http_user_context_1.HttpUserContext);
            const exampleAuthenticatedAction = jest.fn(async (_i) => request_action_1.EmptyResult());
            const authorized = authenticate_1.Authenticate()(exampleAuthenticatedAction);
            const result = await authorized(i);
            expect(result.statusCode).toBe(401);
            expect(result.chunk).toBe(JSON.stringify({ error: 'unauthorized' }));
            expect(result.headers).toEqual({ 'Content-Type': 'application/json' });
            expect(exampleAuthenticatedAction).not.toBeCalled();
        });
    });
    it('Should return 403 with basic auth headers when unauthorized and basic auth is enabled', async () => {
        await utils_1.usingAsync(new inject_1.Injector(), async (i) => {
            const isAuthenticatedAction = jest.fn(async () => false);
            i.setExplicitInstance({ url: 'http://google.com' }, http_1.IncomingMessage);
            i.setExplicitInstance({
                isAuthenticated: isAuthenticatedAction,
                getCurrentUser: async () => Promise.reject(':('),
                authentication: { enableBasicAuth: true },
            }, http_user_context_1.HttpUserContext);
            const exampleAuthenticatedAction = jest.fn(async (_i) => request_action_1.EmptyResult());
            const authorized = authenticate_1.Authenticate()(exampleAuthenticatedAction);
            const result = await authorized(i);
            expect(result.statusCode).toBe(401);
            expect(result.chunk).toBe(JSON.stringify({ error: 'unauthorized' }));
            expect(result.headers).toEqual({ 'Content-Type': 'application/json', 'WWW-Authenticate': 'Basic' });
            expect(exampleAuthenticatedAction).not.toBeCalled();
        });
    });
    it('Should exec the original action if authorized', async () => {
        await utils_1.usingAsync(new inject_1.Injector(), async (i) => {
            const isAuthenticatedAction = jest.fn(async () => true);
            i.setExplicitInstance({ url: 'http://google.com' }, http_1.IncomingMessage);
            i.setExplicitInstance({ isAuthenticated: isAuthenticatedAction, getCurrentUser: async () => Promise.reject(':(') }, http_user_context_1.HttpUserContext);
            const exampleAuthenticatedAction = jest.fn(async (_i) => request_action_1.EmptyResult());
            const authorized = authenticate_1.Authenticate()(exampleAuthenticatedAction);
            const result = await authorized(i);
            expect(result.statusCode).toBe(200);
            expect(result.chunk).toBe(undefined);
            expect(exampleAuthenticatedAction).toBeCalledWith(i);
        });
    });
});
//# sourceMappingURL=authenticate.spec.js.map