"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
require("@furystack/logging");
const http_1 = require("http");
const utils_1 = require("@furystack/utils");
const request_action_1 = require("./models/request-action");
const http_user_context_1 = require("./http-user-context");
exports.Authorize = (...roles) => (action) => {
    return async (i) => {
        const userContext = i.getInstance(http_user_context_1.HttpUserContext);
        try {
            const currentUser = await userContext.getCurrentUser();
            const authorized = await userContext.isAuthorized(...roles);
            if (!authorized) {
                const { url } = i.getInstance(http_1.IncomingMessage);
                await utils_1.sleepAsync(Math.random() * 1000);
                i.logger.warning({
                    scope: '@furystack/http-api/@Authorize()',
                    message: `User '${currentUser.username}' has been tried to access to action '${url}' without the required roles.`,
                    data: {
                        user: currentUser,
                        requiredRoles: roles,
                    },
                });
                return request_action_1.JsonResult({ error: 'forbidden' }, 403);
            }
            return await action(i);
        }
        catch (error) {
            return request_action_1.JsonResult({ error: 'forbidden' }, 403);
        }
    };
};
//# sourceMappingURL=authorize.js.map