"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const http_1 = require("http");
const inject_1 = require("@furystack/inject");
const utils_1 = require("@furystack/utils");
const http_user_context_1 = require("./http-user-context");
const authorize_1 = require("./authorize");
const request_action_1 = require("./models/request-action");
describe('Authorize', () => {
    it('Should return 403 when failed to get current user', async () => {
        await utils_1.usingAsync(new inject_1.Injector(), async (i) => {
            const isAuthorizedAction = jest.fn(async () => false);
            i.setExplicitInstance({ url: 'http://google.com' }, http_1.IncomingMessage);
            i.setExplicitInstance({ isAuthorized: isAuthorizedAction, getCurrentUser: () => Promise.reject(':(') }, http_user_context_1.HttpUserContext);
            const exampleAuthorizedAction = jest.fn(async (_i) => request_action_1.EmptyResult());
            const authorized = authorize_1.Authorize('Role1')(exampleAuthorizedAction);
            const result = await authorized(i);
            expect(result.statusCode).toBe(403);
            expect(result.chunk).toBe(JSON.stringify({ error: 'forbidden' }));
            expect(exampleAuthorizedAction).not.toBeCalled();
        });
    });
    it('Should return 403 if the current user does not have the role', async () => {
        await utils_1.usingAsync(new inject_1.Injector(), async (i) => {
            const isAuthorizedAction = jest.fn(async () => false);
            i.setExplicitInstance({ url: 'http://google.com' }, http_1.IncomingMessage);
            i.setExplicitInstance({
                isAuthorized: isAuthorizedAction,
                getCurrentUser: async () => Promise.resolve({ username: 'a', roles: ['Role1'] }),
            }, http_user_context_1.HttpUserContext);
            const exampleAuthorizedAction = jest.fn(async (_i) => request_action_1.EmptyResult());
            const authorized = authorize_1.Authorize('Role2')(exampleAuthorizedAction);
            const result = await authorized(i);
            expect(result.statusCode).toBe(403);
            expect(result.chunk).toBe(JSON.stringify({ error: 'forbidden' }));
            expect(exampleAuthorizedAction).not.toBeCalled();
        });
    });
    it('Should exec the original action if authorized', async () => {
        await utils_1.usingAsync(new inject_1.Injector(), async (i) => {
            const isAuthorizedAction = jest.fn(async () => true);
            i.setExplicitInstance({ url: 'http://google.com' }, http_1.IncomingMessage);
            i.setExplicitInstance({
                isAuthorized: isAuthorizedAction,
                getCurrentUser: async () => Promise.resolve({ username: 'a', roles: ['Role1'] }),
            }, http_user_context_1.HttpUserContext);
            const exampleAuthorizedAction = jest.fn(async (_i) => request_action_1.EmptyResult());
            const authorized = authorize_1.Authorize('Role1')(exampleAuthorizedAction);
            const result = await authorized(i);
            expect(result.statusCode).toBe(200);
            expect(result.chunk).toBe(undefined);
            expect(exampleAuthorizedAction).toBeCalledWith(i);
        });
    });
});
//# sourceMappingURL=authorize.spec.js.map