"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const http_1 = require("http");
const inject_1 = require("@furystack/inject");
const utils_1 = require("@furystack/utils");
const http_api_settings_1 = require("./http-api-settings");
const utils_2 = require("./utils");
require("./injector-extensions");
/**
 * HTTP Rest API implementation for FuryStack
 */
let HttpApi = class HttpApi {
    constructor(parentInjector) {
        this.injector = parentInjector.createChild({ owner: this });
        this.settings = this.injector.getInstance(http_api_settings_1.HttpApiSettings);
        this.logger = this.injector.logger.withScope(`@furystack/http-api/${this.constructor.name}`);
    }
    async mainRequestListener(incomingMessage, serverResponse) {
        await utils_1.usingAsync(this.injector.createChild({ owner: http_1.IncomingMessage }), async (injector) => {
            injector.setExplicitInstance(incomingMessage, http_1.IncomingMessage);
            injector.setExplicitInstance(serverResponse, http_1.ServerResponse);
            injector.getInstance(utils_2.Utils).addCorsHeaders(this.settings.corsOptions, incomingMessage, serverResponse);
            if (incomingMessage.method === 'OPTIONS') {
                serverResponse.writeHead(200);
                serverResponse.end();
                return;
            }
            const actionMethods = this.settings.actions.map(a => a(injector)).filter(a => a !== undefined);
            if (actionMethods.length > 1) {
                this.logger.error({
                    message: `Multiple HTTP actions found that can be execute the request`,
                    data: {
                        incomingMessage,
                    },
                });
                throw Error(`Multiple HTTP actions found that can be execute the request`);
            }
            if (actionMethods.length === 1) {
                try {
                    const result = await actionMethods[0](injector);
                    serverResponse.sendActionResult(result);
                }
                catch (error) {
                    injector.setExplicitInstance(error, Error);
                    const errorResult = await this.settings.errorAction(injector);
                    serverResponse.sendActionResult(errorResult);
                }
            }
            else {
                const notFoundResult = await this.settings.notFoundAction(injector);
                serverResponse.sendActionResult(notFoundResult);
            }
        });
    }
};
HttpApi = tslib_1.__decorate([
    inject_1.Injectable({ lifetime: 'singleton' }),
    tslib_1.__metadata("design:paramtypes", [inject_1.Injector])
], HttpApi);
exports.HttpApi = HttpApi;
//# sourceMappingURL=http-api.js.map