import { IncomingMessage, ServerResponse } from 'http';
import { PhysicalStore, User, StoreManager } from '@furystack/core';
import { Injector } from '@furystack/inject';
import { HttpAuthenticationSettings } from './http-authentication-settings';
/**
 * Injectable UserContext for FuryStack HTTP Api
 */
export declare class HttpUserContext {
    readonly incomingMessage: IncomingMessage;
    readonly serverResponse: ServerResponse;
    readonly authentication: HttpAuthenticationSettings<User>;
    users: PhysicalStore<User & {
        password: string;
    }>;
    sessions: PhysicalStore<{
        sessionId: string;
        username: string;
    }>;
    private user?;
    /**
     * Returns if the current user is authenticated
     */
    isAuthenticated(): Promise<boolean>;
    /**
     * Returns if the current user can be authorized with ALL of the specified roles
     *
     * @param roles The list of roles to authorize
     */
    isAuthorized(...roles: string[]): Promise<boolean>;
    /**
     * Checks if the system contains a user with the provided name and password, throws an error otherwise
     *
     * @param userName The username
     * @param password The password
     */
    authenticateUser(userName: string, password: string): Promise<{
        username: string;
        roles: string[];
    }>;
    getCurrentUser(): Promise<User>;
    getSessionIdFromRequest(): string | null;
    authenticateRequest(): Promise<User>;
    /**
     * Creates and sets up a cookie-based session for the provided user
     *
     * @param user The user to create a session for
     * @param serverResponse A serverResponse to set the cookie
     */
    cookieLogin(user: User, serverResponse: ServerResponse): Promise<User>;
    cookieLogout(): Promise<void>;
    private readonly logger;
    constructor(incomingMessage: IncomingMessage, serverResponse: ServerResponse, injector: Injector, authentication: HttpAuthenticationSettings<User>, storeManager: StoreManager);
}
//# sourceMappingURL=http-user-context.d.ts.map