/// <reference types="node" />
import { IncomingMessage, ServerResponse } from 'http';
import { ServerOptions } from 'https';
import { User } from '@furystack/core';
import { HttpApiSettings } from './http-api-settings';
import { RouteModel } from './models/route-model';
import { HttpAuthenticationSettings } from './http-authentication-settings';
declare module '@furystack/inject/dist/injector' {
    /**
     * Extended Injector with Http API related methods
     */
    interface Injector {
        /**
         * Sets up the @furystack/http-api with the provided settings
         */
        useHttpApi: (settings?: Partial<HttpApiSettings>) => this;
        /**
         * returns the current Request (IncomingMessage) instance
         */
        getRequest: () => IncomingMessage;
        /**
         * Returns the current Response(ServerResponse) instance
         */
        getResponse: () => ServerResponse;
        /**
         * Sets up the HTTP Authentication
         */
        useHttpAuthentication: <TUser extends User>(settings?: Partial<HttpAuthenticationSettings<TUser>>) => Injector;
        /**
         * Add a specific routing to the HTTP API
         */
        addHttpRouting: (route: RouteModel) => Injector;
        /**
         * Adds the default login / logout routes
         */
        useDefaultLoginRoutes: () => Injector;
        /**
         * Starts the HTTP Listener
         */
        listenHttp: (options?: {
            port?: number;
            hostName?: string;
        }) => Injector;
        /**
         * Starts the HTTPS Listener
         */
        listenHttps: (options: {
            port?: number;
            hostName?: string;
            credentials: ServerOptions;
        }) => Injector;
    }
}
//# sourceMappingURL=injector-extensions.d.ts.map