"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const http_1 = require("http");
const https_1 = require("https");
const core_1 = require("@furystack/core");
const inject_1 = require("@furystack/inject");
const default_login_routes_1 = require("./default-login-routes");
const http_api_1 = require("./http-api");
const http_api_settings_1 = require("./http-api-settings");
const http_authentication_settings_1 = require("./http-authentication-settings");
inject_1.Injector.prototype.getRequest = function () {
    return this.getInstance(http_1.IncomingMessage);
};
inject_1.Injector.prototype.getResponse = function () {
    return this.getInstance(http_1.ServerResponse);
};
inject_1.Injector.prototype.useHttpApi = function (settings) {
    const logger = this.logger.withScope('@furystack/http-api/useHttpApi');
    logger.verbose({
        message: 'Setting up HTTP API...',
        data: settings,
    });
    const oldSettings = this.getInstance(http_api_settings_1.HttpApiSettings);
    this.setExplicitInstance({
        ...oldSettings,
        ...settings,
        actions: [...oldSettings.actions, ...(settings && settings.actions ? settings.actions : [])],
    }, http_api_settings_1.HttpApiSettings);
    this.getInstance(http_api_1.HttpApi);
    return this;
};
inject_1.Injector.prototype.useHttpAuthentication = function (s) {
    this.setExplicitInstance({ ...new http_authentication_settings_1.HttpAuthenticationSettings(), ...s }, http_authentication_settings_1.HttpAuthenticationSettings);
    return this;
};
inject_1.Injector.prototype.listenHttp = function (options) {
    this.logger.withScope('@furystack/http-api/listenHttp').verbose({
        message: `Starting listener at http://${(options && options.hostName) || 'localhost'}:${(options && options.port) ||
            80}`,
    });
    const api = this.getInstance(http_api_1.HttpApi);
    const s = http_1.createServer(api.mainRequestListener.bind(api));
    s.listen(options && options.port, options && options.hostName);
    this.getInstance(core_1.ServerManager).set(s);
    return this;
};
inject_1.Injector.prototype.listenHttps = function (options) {
    this.logger.withScope('@furystack/http-api/listenHttps').verbose({
        message: `Starting listener at https://${(options && options.hostName) || 'localhost'}:${(options &&
            options.port) ||
            80}`,
    });
    const api = this.getInstance(http_api_1.HttpApi);
    const s = https_1.createServer(options.credentials, api.mainRequestListener.bind(api));
    s.listen(options.port, options.hostName);
    this.getInstance(core_1.ServerManager).set(s);
    return this;
};
inject_1.Injector.prototype.addHttpRouting = function (route) {
    this.getInstance(http_api_settings_1.HttpApiSettings).actions.push(route);
    return this;
};
inject_1.Injector.prototype.useDefaultLoginRoutes = function () {
    this.addHttpRouting(default_login_routes_1.defaultLoginRoutes);
    return this;
};
//# sourceMappingURL=injector-extensions.js.map