"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const inject_1 = require("@furystack/inject");
/**
 * A collection of various HTTP API related utilities
 */
let Utils = class Utils {
    /**
     * Reads the post's body and returns a promise with a parsed value
     *
     * @param incomingMessage The incoming message instance
     */
    async readPostBody(incomingMessage) {
        let body = '';
        await new Promise((resolve, reject) => {
            incomingMessage.on('readable', () => {
                const data = incomingMessage.read();
                if (data) {
                    body += data;
                }
            });
            incomingMessage.on('end', () => {
                resolve();
            });
            incomingMessage.on('error', err => {
                reject(err);
            });
        });
        return JSON.parse(body);
    }
    /**
     * Adds the specified CORS headers to the response
     *
     * @param options The CORS Options object
     * @param incomingMessage The incoming message instance
     * @param serverResponse The outgoing response instance
     */
    addCorsHeaders(options, incomingMessage, serverResponse) {
        if (incomingMessage.headers &&
            incomingMessage.headers.origin !== incomingMessage.headers.host &&
            options.origins.some(origin => origin === incomingMessage.headers.origin)) {
            serverResponse.setHeader('Access-Control-Allow-Origin', incomingMessage.headers.origin);
            if (options.credentials) {
                serverResponse.setHeader('Access-Control-Allow-Credentials', 'true');
            }
            if (options.headers && options.headers.length) {
                serverResponse.setHeader('Access-Control-Allow-Headers', options.headers.join(', '));
            }
            if (options.methods && options.methods.length) {
                serverResponse.setHeader('Access-Control-Allow-Methods', options.methods.join(', '));
            }
        }
    }
};
Utils = tslib_1.__decorate([
    inject_1.Injectable({ lifetime: 'transient' })
], Utils);
exports.Utils = Utils;
//# sourceMappingURL=utils.js.map